#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-4AU9WNxIXZ9AevFjRJBgT
key:                  coinbase-pro-0.9.3.2-4AU9WNxIXZ9AevFjRJBgT
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  a2d8a89551771c3f1b0be810475ceb77
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-4AU9WNxIXZ9AevFjRJBgT
depends:
    HsOpenSSL-0.11.7.9-ECOARbZjtpM4CkbjHWG8vn
    aeson-2.2.1.0-ISVQ3jiqbQ6Is6pNVe1jQU
    aeson-casing-0.2.0.0-2HUG7mbV1gvIEVj37iACve
    async-2.2.6-nyFy7OLTowBs5uBnsBun9 base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-FSsVAXZn8WtAF9x9npkm3j exceptions-0.10.7
    http-api-data-0.6.1-5Q7fhik5EOCG2nlnbAlZQ2
    http-client-0.7.19-ItCsqQty15i5Hup0tqhyKm
    http-client-tls-0.3.6.4-83uPLl4XmnQ70LpGBZLm3L
    http-streams-0.8.9.9-A6SVwq59nZwLHOFIelWar0
    http-types-0.12.4-ANoVLVnxqrbENrwWDaCdfA
    io-streams-1.5.2.2-USF0lWuVmOIc8CfEgNImm
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-3WVMCxWJjSRIlAlOqOkCHy
    servant-0.20.3.0-9bGKASKYczNHv7MegeCSSS
    servant-client-0.20.3.0-JuSmy5UmdAxJ83DOGXG9T3
    servant-client-core-0.20.3.0-CTnafYIooiL196bL5L1Gez
    tasty-1.5.2-KXHAZFyA5gEJtE3RSi4Q7N
    tasty-hunit-0.10.2-GaCqQujhYLG1WdKXbBPqy2 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-GRjMn1nqcifEOfZLxgRb5f
    unordered-containers-0.2.20.1-9qQGbgjzyj0ISlxTMt28N2
    uuid-1.3.16-U4CfvBAilMEexniMNpI6E
    vector-0.13.2.0-EpP5e7pcZ78KLpeNqLEk9O
    websockets-0.12.7.3-CAWSpaTYXr98ZiknvauBCg
    wuss-2.0.1.6-DGyDPCHdFO4HeUkklwTZL

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

